
# pypaq

little Python tools, mainly useful for tasks related to machine learning, etc.

-----------------

#### naming conventions used

          
`n_*` - number of *</br>
`*L` - list</br>
`*D` - dict</br>
`*_ix` - index (int)</br>
`*_id` - id (int or str)</br> 
`*_dir` `*_DIR` - directory, folder, relative or absolute</br>
`*_fn` `*_FN` - file name (without dir)</br>
`*_fp` `*_FP` - full path (dir + file_name), relative or absolute</br>
